import sys
from urllib import request, parse, error

ISGD = "https://is.gd/create.php?format=simple&url={url}"
MAX_URL = 128
TIMEOUT = 3  # in seconds

__module_name__ = "urlshortener"
__module_version__ = "0.3"
__module_description__ = "Shortens URLs that are bigger than %d chars" % (MAX_URL,)
__module_author__ = "Facundo Batista <facundo@taniquetil.com.ar>"


def shorten(url):
    """Make an long URL short."""
    service_url = ISGD.format(url=parse.quote(url))
    req = request.Request(service_url, headers={'User-Agent': 'curl/7.47.0'})

    try:
        resp = request.urlopen(req, timeout=TIMEOUT)
    except error.URLError as err:
        print("<-- urlshortener --> Timeout when shortening urls:", err)
        return url

    payload = resp.read()
    return payload.decode("utf8")


def translate(txt):
    """Translate what user said, if needed."""
    # quick exit (not covering all cases, though)
    if 'http' not in txt:
        return

    result = []
    changed = False

    for part in txt.split():
        if (part.startswith("http://") or part.startswith("https://")) and len(part) > MAX_URL:
            result.append(shorten(part))
            changed = True
        else:
            result.append(part)

    if not changed:
        return

    return " ".join(result)


if __name__ == "__main__":
    try:
        import xchat
    except ImportError:
        print(translate(sys.argv[1]))
    else:
        def main(word, word_eol, userdata):
            """URL shortener plugin."""
            txt = translate(word_eol[0])
            if txt is not None:
                xchat.command("SAY " + txt)
                return xchat.EAT_ALL

        xchat.hook_command("", main)
        print("Plugin urlshortener loaded! v3")
